"""
RCABench API

RCABench - A comprehensive root cause analysis benchmarking platform for microservices

The version of the OpenAPI document: 1.1.51
Contact: team@rcabench.com
Generated by OpenAPI Generator (https://rcabench.openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
from enum import Enum

from typing_extensions import Self


class StatusType(int, Enum):
    """
    StatusType
    """

    """
    allowed enum values
    """
    Deleted = -1
    Disabled = 0
    Enabled = 1

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of StatusType from a JSON string"""
        return cls(json.loads(json_str))
