"""
RCABench API

RCABench - A comprehensive root cause analysis benchmarking platform for microservices

The version of the OpenAPI document: 1.1.51
Contact: team@rcabench.com
Generated by OpenAPI Generator (https://rcabench.openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
from typing import Any, ClassVar

from pydantic import BaseModel, ConfigDict, StrictBool, StrictInt, StrictStr
from typing_extensions import Self

from rcabench.openapi.models.container_resp import ContainerResp
from rcabench.openapi.models.dataset_resp import DatasetResp
from rcabench.openapi.models.injection_resp import InjectionResp
from rcabench.openapi.models.label_item import LabelItem


class ProjectDetailResp(BaseModel):
    """
    ProjectDetailResp
    """  # noqa: E501

    containers: list[ContainerResp] | None = None
    created_at: StrictStr | None = None
    datapacks: list[InjectionResp] | None = None
    datasets: list[DatasetResp] | None = None
    description: StrictStr | None = None
    id: StrictInt | None = None
    is_public: StrictBool | None = None
    labels: list[LabelItem] | None = None
    name: StrictStr | None = None
    status: StrictStr | None = None
    updated_at: StrictStr | None = None
    user_count: StrictInt | None = None
    additional_properties: dict[str, Any] = {}
    __properties: ClassVar[list[str]] = [
        "containers",
        "created_at",
        "datapacks",
        "datasets",
        "description",
        "id",
        "is_public",
        "labels",
        "name",
        "status",
        "updated_at",
        "user_count",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return self.model_dump_json(by_alias=True, exclude_unset=True)

    @classmethod
    def from_json(cls, json_str: str) -> Self | None:
        """Create an instance of ProjectDetailResp from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: set[str] = set(
            [
                "additional_properties",
            ]
        )

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in containers (list)
        _items = []
        if self.containers:
            for _item_containers in self.containers:
                if _item_containers:
                    _items.append(_item_containers.to_dict())
            _dict["containers"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in datapacks (list)
        _items = []
        if self.datapacks:
            for _item_datapacks in self.datapacks:
                if _item_datapacks:
                    _items.append(_item_datapacks.to_dict())
            _dict["datapacks"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in datasets (list)
        _items = []
        if self.datasets:
            for _item_datasets in self.datasets:
                if _item_datasets:
                    _items.append(_item_datasets.to_dict())
            _dict["datasets"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in labels (list)
        _items = []
        if self.labels:
            for _item_labels in self.labels:
                if _item_labels:
                    _items.append(_item_labels.to_dict())
            _dict["labels"] = _items
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: dict[str, Any] | None) -> Self | None:
        """Create an instance of ProjectDetailResp from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "containers": [ContainerResp.from_dict(_item) for _item in obj["containers"]]
                if obj.get("containers") is not None
                else None,
                "created_at": obj.get("created_at"),
                "datapacks": [InjectionResp.from_dict(_item) for _item in obj["datapacks"]]
                if obj.get("datapacks") is not None
                else None,
                "datasets": [DatasetResp.from_dict(_item) for _item in obj["datasets"]]
                if obj.get("datasets") is not None
                else None,
                "description": obj.get("description"),
                "id": obj.get("id"),
                "is_public": obj.get("is_public"),
                "labels": [LabelItem.from_dict(_item) for _item in obj["labels"]]
                if obj.get("labels") is not None
                else None,
                "name": obj.get("name"),
                "status": obj.get("status"),
                "updated_at": obj.get("updated_at"),
                "user_count": obj.get("user_count"),
            }
        )
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj
