"""
RCABench API

RCABench - A comprehensive root cause analysis benchmarking platform for microservices

The version of the OpenAPI document: 1.1.51
Contact: team@rcabench.com
Generated by OpenAPI Generator (https://rcabench.openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from typing import Annotated, Any

from pydantic import Field, StrictBool, StrictFloat, StrictInt, StrictStr, validate_call

from rcabench.openapi.api_client import ApiClient, RequestSerialized
from rcabench.openapi.api_response import ApiResponse
from rcabench.openapi.models.container_type import ContainerType
from rcabench.openapi.models.create_container_req import CreateContainerReq
from rcabench.openapi.models.create_container_version_req import CreateContainerVersionReq
from rcabench.openapi.models.generic_response_container_detail_resp import GenericResponseContainerDetailResp
from rcabench.openapi.models.generic_response_container_resp import GenericResponseContainerResp
from rcabench.openapi.models.generic_response_container_version_detail_resp import (
    GenericResponseContainerVersionDetailResp,
)
from rcabench.openapi.models.generic_response_container_version_resp import GenericResponseContainerVersionResp
from rcabench.openapi.models.generic_response_list_container_resp import GenericResponseListContainerResp
from rcabench.openapi.models.generic_response_list_container_version_resp import GenericResponseListContainerVersionResp
from rcabench.openapi.models.generic_response_submit_container_build_resp import GenericResponseSubmitContainerBuildResp
from rcabench.openapi.models.page_size import PageSize
from rcabench.openapi.models.status_type import StatusType
from rcabench.openapi.models.submit_build_container_req import SubmitBuildContainerReq
from rcabench.openapi.rest import RESTResponse, RESTResponseType


class ContainersApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://rcabench.openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_call
    def build_container_image(
        self,
        request: Annotated[SubmitBuildContainerReq, Field(description="Container build request")],
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> GenericResponseSubmitContainerBuildResp:
        """Submit container building

        Submit a container build task to build a container image from provided source files.

        :param request: Container build request (required)
        :type request: SubmitBuildContainerReq
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._build_container_image_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: dict[str, str | None] = {
            "200": "GenericResponseSubmitContainerBuildResp",
            "400": "GenericResponseAny",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "404": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data  # type: ignore

    @validate_call
    def build_container_image_with_http_info(
        self,
        request: Annotated[SubmitBuildContainerReq, Field(description="Container build request")],
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[GenericResponseSubmitContainerBuildResp]:
        """Submit container building

        Submit a container build task to build a container image from provided source files.

        :param request: Container build request (required)
        :type request: SubmitBuildContainerReq
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._build_container_image_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: dict[str, str | None] = {
            "200": "GenericResponseSubmitContainerBuildResp",
            "400": "GenericResponseAny",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "404": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )  # type: ignore

    @validate_call
    def build_container_image_without_preload_content(
        self,
        request: Annotated[SubmitBuildContainerReq, Field(description="Container build request")],
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Submit container building

        Submit a container build task to build a container image from provided source files.

        :param request: Container build request (required)
        :type request: SubmitBuildContainerReq
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._build_container_image_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: dict[str, str | None] = {
            "200": "GenericResponseSubmitContainerBuildResp",
            "400": "GenericResponseAny",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "404": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        return response_data.response

    def _build_container_image_serialize(
        self,
        request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: dict[str, str] = {}

        _path_params: dict[str, str] = {}
        _query_params: list[tuple[str, str]] = []
        _header_params: dict[str, str | None] = _headers or {}
        _form_params: list[tuple[str, str]] = []
        _files: dict[str, str | bytes | list[str] | list[bytes] | list[tuple[str, bytes]]] = {}
        _body_params: bytes | None = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if request is not None:
            _body_params = request

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(["application/json"])

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params["Content-Type"] = _content_type
        else:
            _default_content_type = self.api_client.select_header_content_type(["application/json"])
            if _default_content_type is not None:
                _header_params["Content-Type"] = _default_content_type

        # authentication setting
        _auth_settings: list[str] = ["BearerAuth"]

        return self.api_client.param_serialize(
            method="POST",
            resource_path="/api/v2/containers/build",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def create_container(
        self,
        request: Annotated[CreateContainerReq, Field(description="Container creation request")],
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> GenericResponseContainerResp:
        """Create container

        Create a new container without build configuration.

        :param request: Container creation request (required)
        :type request: CreateContainerReq
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._create_container_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: dict[str, str | None] = {
            "201": "GenericResponseContainerResp",
            "400": "GenericResponseAny",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "409": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data  # type: ignore

    @validate_call
    def create_container_with_http_info(
        self,
        request: Annotated[CreateContainerReq, Field(description="Container creation request")],
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[GenericResponseContainerResp]:
        """Create container

        Create a new container without build configuration.

        :param request: Container creation request (required)
        :type request: CreateContainerReq
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._create_container_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: dict[str, str | None] = {
            "201": "GenericResponseContainerResp",
            "400": "GenericResponseAny",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "409": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )  # type: ignore

    @validate_call
    def create_container_without_preload_content(
        self,
        request: Annotated[CreateContainerReq, Field(description="Container creation request")],
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create container

        Create a new container without build configuration.

        :param request: Container creation request (required)
        :type request: CreateContainerReq
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._create_container_serialize(
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: dict[str, str | None] = {
            "201": "GenericResponseContainerResp",
            "400": "GenericResponseAny",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "409": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        return response_data.response

    def _create_container_serialize(
        self,
        request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: dict[str, str] = {}

        _path_params: dict[str, str] = {}
        _query_params: list[tuple[str, str]] = []
        _header_params: dict[str, str | None] = _headers or {}
        _form_params: list[tuple[str, str]] = []
        _files: dict[str, str | bytes | list[str] | list[bytes] | list[tuple[str, bytes]]] = {}
        _body_params: bytes | None = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if request is not None:
            _body_params = request

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(["application/json"])

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params["Content-Type"] = _content_type
        else:
            _default_content_type = self.api_client.select_header_content_type(["application/json"])
            if _default_content_type is not None:
                _header_params["Content-Type"] = _default_content_type

        # authentication setting
        _auth_settings: list[str] = ["BearerAuth"]

        return self.api_client.param_serialize(
            method="POST",
            resource_path="/api/v2/containers",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def create_container_version(
        self,
        container_id: Annotated[StrictInt, Field(description="Container ID")],
        request: Annotated[CreateContainerVersionReq, Field(description="Container version creation request")],
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> GenericResponseContainerVersionResp:
        """Create container version

        Create a new container version for an existing container.

        :param container_id: Container ID (required)
        :type container_id: int
        :param request: Container version creation request (required)
        :type request: CreateContainerVersionReq
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._create_container_version_serialize(
            container_id=container_id,
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: dict[str, str | None] = {
            "201": "GenericResponseContainerVersionResp",
            "400": "GenericResponseAny",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "409": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data  # type: ignore

    @validate_call
    def create_container_version_with_http_info(
        self,
        container_id: Annotated[StrictInt, Field(description="Container ID")],
        request: Annotated[CreateContainerVersionReq, Field(description="Container version creation request")],
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[GenericResponseContainerVersionResp]:
        """Create container version

        Create a new container version for an existing container.

        :param container_id: Container ID (required)
        :type container_id: int
        :param request: Container version creation request (required)
        :type request: CreateContainerVersionReq
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._create_container_version_serialize(
            container_id=container_id,
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: dict[str, str | None] = {
            "201": "GenericResponseContainerVersionResp",
            "400": "GenericResponseAny",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "409": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )  # type: ignore

    @validate_call
    def create_container_version_without_preload_content(
        self,
        container_id: Annotated[StrictInt, Field(description="Container ID")],
        request: Annotated[CreateContainerVersionReq, Field(description="Container version creation request")],
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create container version

        Create a new container version for an existing container.

        :param container_id: Container ID (required)
        :type container_id: int
        :param request: Container version creation request (required)
        :type request: CreateContainerVersionReq
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._create_container_version_serialize(
            container_id=container_id,
            request=request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: dict[str, str | None] = {
            "201": "GenericResponseContainerVersionResp",
            "400": "GenericResponseAny",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "409": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        return response_data.response

    def _create_container_version_serialize(
        self,
        container_id,
        request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: dict[str, str] = {}

        _path_params: dict[str, str] = {}
        _query_params: list[tuple[str, str]] = []
        _header_params: dict[str, str | None] = _headers or {}
        _form_params: list[tuple[str, str]] = []
        _files: dict[str, str | bytes | list[str] | list[bytes] | list[tuple[str, bytes]]] = {}
        _body_params: bytes | None = None

        # process the path parameters
        if container_id is not None:
            _path_params["container_id"] = container_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if request is not None:
            _body_params = request

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(["application/json"])

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params["Content-Type"] = _content_type
        else:
            _default_content_type = self.api_client.select_header_content_type(["application/json"])
            if _default_content_type is not None:
                _header_params["Content-Type"] = _default_content_type

        # authentication setting
        _auth_settings: list[str] = ["BearerAuth"]

        return self.api_client.param_serialize(
            method="POST",
            resource_path="/api/v2/containers/{container_id}/versions",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def get_container_by_id(
        self,
        container_id: Annotated[StrictInt, Field(description="Container ID")],
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> GenericResponseContainerDetailResp:
        """Get container by ID

        Get detailed information about a specific container

        :param container_id: Container ID (required)
        :type container_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_container_by_id_serialize(
            container_id=container_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: dict[str, str | None] = {
            "200": "GenericResponseContainerDetailResp",
            "400": "GenericResponseAny",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "404": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data  # type: ignore

    @validate_call
    def get_container_by_id_with_http_info(
        self,
        container_id: Annotated[StrictInt, Field(description="Container ID")],
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[GenericResponseContainerDetailResp]:
        """Get container by ID

        Get detailed information about a specific container

        :param container_id: Container ID (required)
        :type container_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_container_by_id_serialize(
            container_id=container_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: dict[str, str | None] = {
            "200": "GenericResponseContainerDetailResp",
            "400": "GenericResponseAny",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "404": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )  # type: ignore

    @validate_call
    def get_container_by_id_without_preload_content(
        self,
        container_id: Annotated[StrictInt, Field(description="Container ID")],
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get container by ID

        Get detailed information about a specific container

        :param container_id: Container ID (required)
        :type container_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_container_by_id_serialize(
            container_id=container_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: dict[str, str | None] = {
            "200": "GenericResponseContainerDetailResp",
            "400": "GenericResponseAny",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "404": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        return response_data.response

    def _get_container_by_id_serialize(
        self,
        container_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: dict[str, str] = {}

        _path_params: dict[str, str] = {}
        _query_params: list[tuple[str, str]] = []
        _header_params: dict[str, str | None] = _headers or {}
        _form_params: list[tuple[str, str]] = []
        _files: dict[str, str | bytes | list[str] | list[bytes] | list[tuple[str, bytes]]] = {}
        _body_params: bytes | None = None

        # process the path parameters
        if container_id is not None:
            _path_params["container_id"] = container_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(["application/json"])

        # authentication setting
        _auth_settings: list[str] = ["BearerAuth"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/api/v2/containers/{container_id}",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def get_container_version_by_id(
        self,
        container_id: Annotated[StrictInt, Field(description="Container ID")],
        version_id: Annotated[StrictInt, Field(description="Container Version ID")],
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> GenericResponseContainerVersionDetailResp:
        """Get container version by ID

        Get detailed information about a specific container version

        :param container_id: Container ID (required)
        :type container_id: int
        :param version_id: Container Version ID (required)
        :type version_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_container_version_by_id_serialize(
            container_id=container_id,
            version_id=version_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: dict[str, str | None] = {
            "200": "GenericResponseContainerVersionDetailResp",
            "400": "GenericResponseAny",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "404": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data  # type: ignore

    @validate_call
    def get_container_version_by_id_with_http_info(
        self,
        container_id: Annotated[StrictInt, Field(description="Container ID")],
        version_id: Annotated[StrictInt, Field(description="Container Version ID")],
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[GenericResponseContainerVersionDetailResp]:
        """Get container version by ID

        Get detailed information about a specific container version

        :param container_id: Container ID (required)
        :type container_id: int
        :param version_id: Container Version ID (required)
        :type version_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_container_version_by_id_serialize(
            container_id=container_id,
            version_id=version_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: dict[str, str | None] = {
            "200": "GenericResponseContainerVersionDetailResp",
            "400": "GenericResponseAny",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "404": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )  # type: ignore

    @validate_call
    def get_container_version_by_id_without_preload_content(
        self,
        container_id: Annotated[StrictInt, Field(description="Container ID")],
        version_id: Annotated[StrictInt, Field(description="Container Version ID")],
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get container version by ID

        Get detailed information about a specific container version

        :param container_id: Container ID (required)
        :type container_id: int
        :param version_id: Container Version ID (required)
        :type version_id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_container_version_by_id_serialize(
            container_id=container_id,
            version_id=version_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: dict[str, str | None] = {
            "200": "GenericResponseContainerVersionDetailResp",
            "400": "GenericResponseAny",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "404": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        return response_data.response

    def _get_container_version_by_id_serialize(
        self,
        container_id,
        version_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: dict[str, str] = {}

        _path_params: dict[str, str] = {}
        _query_params: list[tuple[str, str]] = []
        _header_params: dict[str, str | None] = _headers or {}
        _form_params: list[tuple[str, str]] = []
        _files: dict[str, str | bytes | list[str] | list[bytes] | list[tuple[str, bytes]]] = {}
        _body_params: bytes | None = None

        # process the path parameters
        if container_id is not None:
            _path_params["container_id"] = container_id
        if version_id is not None:
            _path_params["version_id"] = version_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(["application/json"])

        # authentication setting
        _auth_settings: list[str] = ["BearerAuth"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/api/v2/containers/{container_id}/versions/{version_id}",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def list_container_versions(
        self,
        container_id: Annotated[StrictInt, Field(description="Container ID")],
        page: Annotated[StrictInt | None, Field(description="Page number")] = None,
        size: Annotated[StrictInt | None, Field(description="Page size")] = None,
        status: Annotated[StatusType | None, Field(description="Container version status filter")] = None,
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> GenericResponseListContainerVersionResp:
        """List container versions

        Get paginated list of container versions for a specific container

        :param container_id: Container ID (required)
        :type container_id: int
        :param page: Page number
        :type page: int
        :param size: Page size
        :type size: int
        :param status: Container version status filter
        :type status: StatusType
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._list_container_versions_serialize(
            container_id=container_id,
            page=page,
            size=size,
            status=status,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: dict[str, str | None] = {
            "200": "GenericResponseListContainerVersionResp",
            "400": "GenericResponseAny",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data  # type: ignore

    @validate_call
    def list_container_versions_with_http_info(
        self,
        container_id: Annotated[StrictInt, Field(description="Container ID")],
        page: Annotated[StrictInt | None, Field(description="Page number")] = None,
        size: Annotated[StrictInt | None, Field(description="Page size")] = None,
        status: Annotated[StatusType | None, Field(description="Container version status filter")] = None,
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[GenericResponseListContainerVersionResp]:
        """List container versions

        Get paginated list of container versions for a specific container

        :param container_id: Container ID (required)
        :type container_id: int
        :param page: Page number
        :type page: int
        :param size: Page size
        :type size: int
        :param status: Container version status filter
        :type status: StatusType
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._list_container_versions_serialize(
            container_id=container_id,
            page=page,
            size=size,
            status=status,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: dict[str, str | None] = {
            "200": "GenericResponseListContainerVersionResp",
            "400": "GenericResponseAny",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )  # type: ignore

    @validate_call
    def list_container_versions_without_preload_content(
        self,
        container_id: Annotated[StrictInt, Field(description="Container ID")],
        page: Annotated[StrictInt | None, Field(description="Page number")] = None,
        size: Annotated[StrictInt | None, Field(description="Page size")] = None,
        status: Annotated[StatusType | None, Field(description="Container version status filter")] = None,
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List container versions

        Get paginated list of container versions for a specific container

        :param container_id: Container ID (required)
        :type container_id: int
        :param page: Page number
        :type page: int
        :param size: Page size
        :type size: int
        :param status: Container version status filter
        :type status: StatusType
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._list_container_versions_serialize(
            container_id=container_id,
            page=page,
            size=size,
            status=status,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: dict[str, str | None] = {
            "200": "GenericResponseListContainerVersionResp",
            "400": "GenericResponseAny",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        return response_data.response

    def _list_container_versions_serialize(
        self,
        container_id,
        page,
        size,
        status,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: dict[str, str] = {}

        _path_params: dict[str, str] = {}
        _query_params: list[tuple[str, str]] = []
        _header_params: dict[str, str | None] = _headers or {}
        _form_params: list[tuple[str, str]] = []
        _files: dict[str, str | bytes | list[str] | list[bytes] | list[tuple[str, bytes]]] = {}
        _body_params: bytes | None = None

        # process the path parameters
        if container_id is not None:
            _path_params["container_id"] = container_id
        # process the query parameters
        if page is not None:
            _query_params.append(("page", page))

        if size is not None:
            _query_params.append(("size", size))

        if status is not None:
            _query_params.append(("status", status.value))

        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(["application/json"])

        # authentication setting
        _auth_settings: list[str] = ["BearerAuth"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/api/v2/containers/{container_id}/versions",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def list_containers(
        self,
        page: Annotated[StrictInt | None, Field(description="Page number")] = None,
        size: Annotated[PageSize | None, Field(description="Page size")] = None,
        type: Annotated[ContainerType | None, Field(description="Container type filter")] = None,
        is_public: Annotated[StrictBool | None, Field(description="Container public visibility filter")] = None,
        status: Annotated[StatusType | None, Field(description="Container status filter")] = None,
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> GenericResponseListContainerResp:
        """List containers

        Get paginated list of containers with pagination and filtering

        :param page: Page number
        :type page: int
        :param size: Page size
        :type size: PageSize
        :param type: Container type filter
        :type type: ContainerType
        :param is_public: Container public visibility filter
        :type is_public: bool
        :param status: Container status filter
        :type status: StatusType
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._list_containers_serialize(
            page=page,
            size=size,
            type=type,
            is_public=is_public,
            status=status,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: dict[str, str | None] = {
            "200": "GenericResponseListContainerResp",
            "400": "GenericResponseAny",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data  # type: ignore

    @validate_call
    def list_containers_with_http_info(
        self,
        page: Annotated[StrictInt | None, Field(description="Page number")] = None,
        size: Annotated[PageSize | None, Field(description="Page size")] = None,
        type: Annotated[ContainerType | None, Field(description="Container type filter")] = None,
        is_public: Annotated[StrictBool | None, Field(description="Container public visibility filter")] = None,
        status: Annotated[StatusType | None, Field(description="Container status filter")] = None,
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[GenericResponseListContainerResp]:
        """List containers

        Get paginated list of containers with pagination and filtering

        :param page: Page number
        :type page: int
        :param size: Page size
        :type size: PageSize
        :param type: Container type filter
        :type type: ContainerType
        :param is_public: Container public visibility filter
        :type is_public: bool
        :param status: Container status filter
        :type status: StatusType
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._list_containers_serialize(
            page=page,
            size=size,
            type=type,
            is_public=is_public,
            status=status,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: dict[str, str | None] = {
            "200": "GenericResponseListContainerResp",
            "400": "GenericResponseAny",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )  # type: ignore

    @validate_call
    def list_containers_without_preload_content(
        self,
        page: Annotated[StrictInt | None, Field(description="Page number")] = None,
        size: Annotated[PageSize | None, Field(description="Page size")] = None,
        type: Annotated[ContainerType | None, Field(description="Container type filter")] = None,
        is_public: Annotated[StrictBool | None, Field(description="Container public visibility filter")] = None,
        status: Annotated[StatusType | None, Field(description="Container status filter")] = None,
        _request_timeout: None
        | Annotated[StrictFloat, Field(gt=0)]
        | tuple[Annotated[StrictStr, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]] = None,
        _request_auth: dict[StrictStr, Any] | None = None,
        _content_type: StrictStr | None = None,
        _headers: dict[StrictStr, Any] | None = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List containers

        Get paginated list of containers with pagination and filtering

        :param page: Page number
        :type page: int
        :param size: Page size
        :type size: PageSize
        :param type: Container type filter
        :type type: ContainerType
        :param is_public: Container public visibility filter
        :type is_public: bool
        :param status: Container status filter
        :type status: StatusType
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._list_containers_serialize(
            page=page,
            size=size,
            type=type,
            is_public=is_public,
            status=status,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: dict[str, str | None] = {
            "200": "GenericResponseListContainerResp",
            "400": "GenericResponseAny",
            "401": "GenericResponseAny",
            "403": "GenericResponseAny",
            "500": "GenericResponseAny",
        }
        response_data = self.api_client.call_api(*_param, _request_timeout=_request_timeout)

        assert response_data is not None and isinstance(response_data, RESTResponse), (
            "Response data must be of type RESTResponse"
        )
        return response_data.response

    def _list_containers_serialize(
        self,
        page,
        size,
        type,
        is_public,
        status,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: dict[str, str] = {}

        _path_params: dict[str, str] = {}
        _query_params: list[tuple[str, str]] = []
        _header_params: dict[str, str | None] = _headers or {}
        _form_params: list[tuple[str, str]] = []
        _files: dict[str, str | bytes | list[str] | list[bytes] | list[tuple[str, bytes]]] = {}
        _body_params: bytes | None = None

        # process the path parameters
        # process the query parameters
        if page is not None:
            _query_params.append(("page", page))

        if size is not None:
            _query_params.append(("size", size.value))

        if type is not None:
            _query_params.append(("type", type.value))

        if is_public is not None:
            _query_params.append(("is_public", is_public))

        if status is not None:
            _query_params.append(("status", status.value))

        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(["application/json"])

        # authentication setting
        _auth_settings: list[str] = ["BearerAuth"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/api/v2/containers",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )
